@@ -306,15 +306,6 @@ bonobo_pbproxy_set_bag (BonoboPBProxy     *proxy,
 
 	proxy->lid = 0;
 
-	/* fixme: we must unref the bag, but it seems there is a ref counting
-	   error somewhere - so I just disabled it */
-	/*
-	  if (proxy->bag != CORBA_OBJECT_NIL)
-	  bonobo_object_release_unref (proxy->bag, NULL);
-	*/
-
-	proxy->bag = CORBA_OBJECT_NIL;
-
 	for (l = proxy->pl; l; l = l->next) {
 		pd = (PropertyData *)l->data;
 
@@ -324,6 +315,11 @@ bonobo_pbproxy_set_bag (BonoboPBProxy     *proxy,
 		}
 	}
 
+	if (proxy->bag != CORBA_OBJECT_NIL)
+		bonobo_object_release_unref (proxy->bag, NULL);
+
+	proxy->bag = CORBA_OBJECT_NIL;
+
 	CORBA_exception_init (&ev);
 
 	if (bag != CORBA_OBJECT_NIL) {
@@ -378,6 +374,9 @@ bonobo_pbproxy_set_bag (BonoboPBProxy     *proxy,
 					CORBA_free (pd->value);
 
 				pd->value = value;
+
+				bonobo_event_source_notify_listeners_full
+					(proxy->es, "Bonobo/Property", "change", pd->name, value, &ev);
 			}
 
 			CORBA_free (pn);
@@ -602,21 +601,18 @@ bonobo_pbproxy_update (BonoboPBProxy *proxy)
 	GList *l;
 	PropertyData *pd;
 	CORBA_Environment ev;
-	
-	l = proxy->pl;
-
-	while (l) {
-		pd = (PropertyData *)l->data;
 
+	for (l = proxy->pl; l != NULL; l = l->next) {
 		CORBA_exception_init (&ev);
+	
+		pd = (PropertyData *)l->data;
 		
 		if (pd->new_value && pd->property != CORBA_OBJECT_NIL)
 			Bonobo_Property_setValue (pd->property, 
 						  pd->new_value, &ev);
 
-		l = l->next;
+		CORBA_exception_free (&ev);
 	}
-	CORBA_exception_free (&ev);
 }
 
 void
