@@ -25,7 +25,7 @@ static void
 changed_cb (GtkEntry *entry,
 	    gpointer user_data)
 {
-	BonoboPropertyEditor *editor = BONOBO_PROPERTY_EDITOR (user_data);
+	BonoboPEditor *editor = BONOBO_PEDITOR (user_data);
 	CORBA_Environment ev;
 	DynamicAny_DynAny dyn = NULL;
 	CORBA_TypeCode tc;
@@ -100,7 +100,7 @@ changed_cb (GtkEntry *entry,
 
 	arg = DynamicAny_DynAny_to_any (dyn, &ev);
 
-	bonobo_property_editor_set_value (editor, arg, &ev);
+	bonobo_peditor_set_value (editor, arg, &ev);
 
 	bonobo_arg_release (arg);
 
@@ -110,15 +110,15 @@ changed_cb (GtkEntry *entry,
 }
 
 static void
-set_value_cb (BonoboPropertyEditor *editor,
-	      BonoboArg            *value,
-	      CORBA_Environment    *ev)
+set_value_cb (BonoboPEditor     *editor,
+	      BonoboArg         *value,
+	      CORBA_Environment *ev)
 {
 	DynamicAny_DynAny dyn;
 	GtkEntry *entry;
 	char *text;
 
-	entry = GTK_ENTRY (GTK_BIN (editor)->child);
+	entry = GTK_ENTRY (bonobo_peditor_get_widget (editor));
 
 	dyn = CORBA_ORB_create_dyn_any (bonobo_orb (), value, ev);
 
@@ -190,14 +190,14 @@ set_value_cb (BonoboPropertyEditor *editor,
 }
 
 static void
-spin_set_value_cb (BonoboPropertyEditor *editor,
-		   BonoboArg            *value,
-		   CORBA_Environment    *ev)
+spin_set_value_cb (BonoboPEditor     *editor,
+		   BonoboArg         *value,
+		   CORBA_Environment *ev)
 {
 	GtkEntry *entry;
 	guint32 v;
 
-	entry = GTK_ENTRY (GTK_BIN (editor)->child);
+	entry = GTK_ENTRY (bonobo_peditor_get_widget (editor));
 
 	if (!check_type (value->_type, TC_long))
 		return;
@@ -213,28 +213,52 @@ spin_set_value_cb (BonoboPropertyEditor *editor,
 					    editor);
 }
 
-static GtkWidget *
-bonobo_property_editor_basic_new (CORBA_TypeCode tc)
+static GtkObject *
+bonobo_peditor_basic_construct (GtkWidget *widget, CORBA_TypeCode tc)
+{
+	BonoboPEditor *editor;
+
+	g_return_val_if_fail (widget != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_ENTRY (widget), NULL);
+
+	editor = bonobo_peditor_construct (widget, set_value_cb, tc);
+
+	gtk_signal_connect (GTK_OBJECT (widget), "changed",
+			    (GtkSignalFunc) changed_cb, editor);
+
+	return GTK_OBJECT (editor);
+}
+
+static GtkObject *
+bonobo_peditor_basic_new (CORBA_TypeCode tc)
 {
-	BonoboPropertyEditor *editor;
 	GtkWidget *entry;
 	
 	entry = gtk_entry_new ();
 	gtk_widget_show (entry);
 
-	editor = bonobo_property_editor_construct (entry, set_value_cb, tc);
-	gtk_widget_show (GTK_WIDGET (editor));
-
-	gtk_signal_connect (GTK_OBJECT (entry), "changed",
-			    (GtkSignalFunc) changed_cb, editor);
-
-	return GTK_WIDGET (editor);
+	return bonobo_peditor_basic_construct (entry, tc);
 }
 
-GtkWidget *
-bonobo_property_editor_int_range_new (gint32 lower, gint32 upper, gint32 incr)
+GtkObject *
+bonobo_peditor_int_range_construct (GtkWidget *widget)
+{
+	BonoboPEditor *editor;
+	
+	g_return_val_if_fail (widget != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_SPIN_BUTTON (widget), NULL);
+
+	editor = bonobo_peditor_construct (widget, spin_set_value_cb, TC_long);
+
+	gtk_signal_connect (GTK_OBJECT (widget), "changed",
+			    (GtkSignalFunc) changed_cb, editor);
+
+	return GTK_OBJECT (editor);
+}
+
+GtkObject *
+bonobo_peditor_int_range_new (gint32 lower, gint32 upper, gint32 incr)
 {
-	BonoboPropertyEditor *editor;
 	GtkObject            *adj;
 	GtkWidget            *entry;
 	
@@ -245,58 +269,89 @@ bonobo_property_editor_int_range_new (gint32 lower, gint32 upper, gint32 incr)
  
 	gtk_widget_show (entry);
 
-	editor = bonobo_property_editor_construct (entry, spin_set_value_cb, 
-						   TC_long);
-	gtk_widget_show (GTK_WIDGET (editor));
-
-	gtk_signal_connect (GTK_OBJECT (entry), "changed",
-			    (GtkSignalFunc) changed_cb, editor);
-
-	return GTK_WIDGET (editor);
+	return bonobo_peditor_int_range_construct (entry);
 }
 
-GtkWidget *
-bonobo_property_editor_short_new ()
+GtkObject *
+bonobo_peditor_short_new ()
 {
-	return bonobo_property_editor_basic_new (TC_short);
+	return bonobo_peditor_basic_new (TC_short);
 }
 
-GtkWidget *
-bonobo_property_editor_ushort_new ()
+GtkObject *
+bonobo_peditor_ushort_new ()
 {
-	return bonobo_property_editor_basic_new (TC_ushort);
+	return bonobo_peditor_basic_new (TC_ushort);
 }
 
-GtkWidget *
-bonobo_property_editor_long_new ()
+GtkObject *
+bonobo_peditor_long_new ()
 {
-	return bonobo_property_editor_basic_new (TC_long);
+	return bonobo_peditor_basic_new (TC_long);
 }
 
-GtkWidget *
-bonobo_property_editor_ulong_new ()
+GtkObject *
+bonobo_peditor_ulong_new ()
 {
-	return bonobo_property_editor_basic_new (TC_ulong);
+	return bonobo_peditor_basic_new (TC_ulong);
 }
 
-GtkWidget *
-bonobo_property_editor_float_new ()
+GtkObject *
+bonobo_peditor_float_new ()
 {
-	return bonobo_property_editor_basic_new (TC_float);
+	return bonobo_peditor_basic_new (TC_float);
 }
 
-GtkWidget *
-bonobo_property_editor_double_new ()
+GtkObject *
+bonobo_peditor_double_new ()
 {
-	return bonobo_property_editor_basic_new (TC_double);
+	return bonobo_peditor_basic_new (TC_double);
 }
 
-GtkWidget *
-bonobo_property_editor_string_new ()
+GtkObject *
+bonobo_peditor_string_new ()
 {
-	return bonobo_property_editor_basic_new (TC_string);
+	return bonobo_peditor_basic_new (TC_string);
 }
 
+GtkObject *
+bonobo_peditor_short_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_short);
+}
 
+GtkObject *
+bonobo_peditor_ushort_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_ushort);
+}
 
+GtkObject *
+bonobo_peditor_long_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_long);
+}
 
+GtkObject *
+bonobo_peditor_ulong_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_ulong);
+}
+
+GtkObject *
+bonobo_peditor_float_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_float);
+}
+
+GtkObject *
+bonobo_peditor_double_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_double);
+}
+
+GtkObject *
+bonobo_peditor_string_construct (GtkWidget *widget)
+{
+	return bonobo_peditor_basic_construct (widget, TC_string);
+}
