@@ -17,7 +17,7 @@ static void
 toggled_cb (GtkToggleButton *toggle,
 	    gpointer         user_data) 
 {
-	BonoboPropertyEditor *editor = BONOBO_PROPERTY_EDITOR (user_data);
+	BonoboPEditor *editor = BONOBO_PEDITOR (user_data);
 	CORBA_Environment ev;
 	BonoboArg *arg;
 	gboolean active;
@@ -29,7 +29,7 @@ toggled_cb (GtkToggleButton *toggle,
 
 	BONOBO_ARG_SET_BOOLEAN (arg, active);
 
-	bonobo_property_editor_set_value (editor, arg, &ev);
+	bonobo_peditor_set_value (editor, arg, &ev);
 
 	bonobo_arg_release (arg);
 
@@ -37,9 +37,9 @@ toggled_cb (GtkToggleButton *toggle,
 }
 
 static void
-set_value_cb (BonoboPropertyEditor *editor,
-	      BonoboArg            *value,
-	      CORBA_Environment    *ev)
+set_value_cb (BonoboPEditor     *editor,
+	      BonoboArg         *value,
+	      CORBA_Environment *ev)
 {
 	GtkWidget *widget;
 	CORBA_boolean new_value;
@@ -47,29 +47,38 @@ set_value_cb (BonoboPropertyEditor *editor,
 	if (!bonobo_arg_type_is_equal (value->_type, TC_boolean, NULL))
 		return;
 
-	widget = GTK_BIN (editor)->child;
+	widget = bonobo_peditor_get_widget (editor);
 
 	new_value = BONOBO_ARG_GET_BOOLEAN (value);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), new_value);
 }
 
-GtkWidget *
-bonobo_property_editor_boolean_new (const char *label)
+GtkObject *
+bonobo_peditor_boolean_new (const char *label)
 {
 	GtkWidget *check;
-	BonoboPropertyEditor *ed;
 
 	if (label)
 		check = gtk_check_button_new_with_label (label);
 	else
 		check = gtk_check_button_new ();
 
-	ed = bonobo_property_editor_construct (check, set_value_cb, 
-					       TC_boolean);
+	return bonobo_peditor_boolean_construct (check);
+}
 
-	gtk_signal_connect (GTK_OBJECT (check), "toggled",
+GtkObject *
+bonobo_peditor_boolean_construct (GtkWidget *widget) 
+{
+	BonoboPEditor *ed;
+
+	g_return_val_if_fail (widget != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_CHECK_BUTTON (widget), NULL);
+
+	ed = bonobo_peditor_construct (widget, set_value_cb, TC_boolean);
+
+	gtk_signal_connect (GTK_OBJECT (widget), "toggled",
 			    (GtkSignalFunc) toggled_cb, ed);
-
-	return GTK_WIDGET (ed);
+	
+	return GTK_OBJECT (ed);
 }
