@@ -15,15 +15,14 @@
 #include "bonobo-config-utils.h"
 
 static void
-set_value_cb (BonoboPropertyEditor *editor,
-	      BonoboArg            *value,
-	      CORBA_Environment    *ev)
+set_value_cb (BonoboPEditor     *editor,
+	      BonoboArg         *value,
+	      CORBA_Environment *ev)
 {
 	GtkWidget *e;
 	char *s;
 
-	e = GTK_BIN (editor)->child;
-
+	e = bonobo_peditor_get_widget (editor);
 	s = bonobo_config_any_to_string (value);
 	
 	gtk_entry_set_text (GTK_ENTRY (e), s);
@@ -31,17 +30,27 @@ set_value_cb (BonoboPropertyEditor *editor,
 	g_free (s);
 }
 
-GtkWidget *
-bonobo_property_editor_default_new ()
+GtkObject *
+bonobo_peditor_default_new ()
 {
 	GtkWidget *e;
-	BonoboPropertyEditor *ed;
 
 	e = gtk_entry_new ();
 	gtk_entry_set_text (GTK_ENTRY (e), "no value set");
 	gtk_entry_set_editable (GTK_ENTRY (e), FALSE);
 
-	ed = bonobo_property_editor_construct (e, set_value_cb, NULL);
+	return bonobo_peditor_default_construct (e);
+}
 
-	return GTK_WIDGET (ed);
+GtkObject *
+bonobo_peditor_default_construct (GtkWidget *widget) 
+{
+	BonoboPEditor *ed;
+
+	g_return_val_if_fail (widget != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_ENTRY (widget), NULL);
+
+	ed = bonobo_peditor_construct (widget, set_value_cb, NULL);
+
+	return GTK_OBJECT (ed);
 }
