@@ -193,7 +193,7 @@ real_get_value (BonoboConfigDatabase *db,
 
 	if (de->value)
 		return bonobo_arg_copy (de->value);
-	
+
 	/* localized value */
 	if (de->node && de->node->childs && de->node->childs->next)	
 		value = bonobo_config_xml_decode_any ((BonoboUINode *)de->node,
@@ -223,7 +223,7 @@ real_sync (BonoboConfigDatabase *db,
 		return;
 	}
 
-	// chmod (tmp_name, 0664);
+	/* chmod (tmp_name, 0664); */
 
 	if (rename (tmp_name, xmldb->filename) < 0) {
 		g_free (tmp_name);
@@ -303,6 +303,10 @@ real_set_value (BonoboConfigDatabase *db,
 	char *name;
 
 	de = lookup_dir_entry (xmldb, key, TRUE);
+	if (!de) {
+		bonobo_exception_set (ev, ex_Bonobo_ConfigDatabase_NotFound);
+		return;
+	}
 
 	if (de->value)
 		CORBA_free (de->value);
