@@ -35,6 +35,11 @@ test_xmldb ()
 	value = bonobo_arg_new (TC_long);
 	BONOBO_ARG_SET_LONG (value, 5);
 	
+	/* we cant set values on directory names */
+	Bonobo_ConfigDatabase_setValue (db, "/adaf/safadsd/", value, &ev);
+	g_assert (BONOBO_EX (&ev));
+        CORBA_exception_init (&ev);
+
 	Bonobo_ConfigDatabase_setValue (db, "/test", value, &ev);
 	g_assert (!BONOBO_EX (&ev));
 
@@ -83,6 +88,94 @@ test_xmldb ()
 	Bonobo_ConfigDatabase_setValue (db, "/storagetype", value, &ev);
 	g_assert (!BONOBO_EX (&ev));
 
+
+	{
+		gboolean r, def = FALSE, b = TRUE;
+
+		bonobo_config_set_boolean (db, "/test/boolean", b, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		r = bonobo_config_get_boolean (db, "/test/boolean", &ev);
+		g_assert (!BONOBO_EX (&ev));
+		g_assert (r == 1);
+
+		r = bonobo_config_get_boolean_with_default (db, 
+                        "/test/boolean", FALSE, &def);
+		g_assert (!def);
+		g_assert (r == 1);	
+	}
+
+	{
+		char *str;
+
+		str = "TEST";
+		bonobo_config_set_string (db, "/test/string", str, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		str = bonobo_config_get_string (db, "/test/string", &ev);
+		g_assert (!BONOBO_EX (&ev));
+		g_assert (!strcmp ("TEST", str));
+	}
+
+	{
+		gint16 val = -5;
+
+		bonobo_config_set_short (db, "/test/short", val, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		val = bonobo_config_get_short (db, "/test/short", &ev);
+		g_assert (!BONOBO_EX (&ev));
+		g_assert (val == -5);
+	}
+
+	{
+		guint16 val = 5;
+
+		bonobo_config_set_ushort (db, "/test/ushort", val, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		val = bonobo_config_get_ushort (db, "/test/ushort", &ev);
+		g_assert (!BONOBO_EX (&ev));
+		g_assert (val == 5);
+	}
+
+	{
+		glong val = -15;
+
+		bonobo_config_set_long (db, "/test/long", val, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		val = bonobo_config_get_long (db, "/test/long", &ev);
+		g_assert (!BONOBO_EX (&ev));
+		g_assert (val == -15);
+	}
+
+	{
+		gfloat val = 1.25;
+
+		bonobo_config_set_float (db, "/test/float", val, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		val = bonobo_config_get_float (db, "/test/float", &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		g_assert (((int)(val*1000)) == 1250);
+	}
+
+	{
+		gdouble val = 1.125;
+
+		bonobo_config_set_double (db, "/test/double", val, &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		val = bonobo_config_get_double (db, "/test/double", &ev);
+		g_assert (!BONOBO_EX (&ev));
+
+		g_assert (((int)(val*1000)) == 1125);
+	}
+
+	
+
 	Bonobo_ConfigDatabase_sync (db, &ev);
 	g_assert (!BONOBO_EX (&ev));
 }
@@ -91,7 +184,6 @@ static void
 read_data (Bonobo_ConfigDatabase db)
 {
         CORBA_Environment ev;
-	CORBA_any *value;
 	Bonobo_KeyList *klist;
 	
         CORBA_exception_init (&ev);
@@ -223,7 +315,7 @@ static gint
 run_tests ()
 {
 	test_xmldirdb ();
-
+	test_xmldb ();
 
 	gtk_main_quit ();
 
